/*
 * Éditez ce fichier et copiez-le comme userContent.css dans votre
 * dossier-de-profil/chrome/
 */

/*
 * Ce fichier peut être utilisé pour appliquer un style sur toutes les pages web visitées.
 * Les règles qui ne sont pas suivies de !important seront écrasées par les règles définies par l'auteur
 * de la page. Les règles suivies de !important écraseront par contre celles définies par l'auteur.
 */

/*
 * exemple : empêcher l'élément "blink" de clignoter
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * exemple : donner une bordure de 2 pixels à tous les tableaux
 *
 * table { border: 2px solid; }
 */

/*
 * exemple : désactiver le défilement de l'élément "marquee"
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/* 
 * Pour d'autres exemples, voir http://www.mozilla.org/unix/customizing.html
 */

